@@ -23,9 +23,10 @@ import logging
 import os
 import sys
 import unittest
-import pytest
 from os.path import join, dirname
 
+import pytest
+
 from python_base_app import configuration
 from python_base_app import log_handling
 
@@ -204,11 +205,21 @@ class BaseTestCase(unittest.TestCase):
 
         return join(self._test_data_base_dir, p_rel_path)
 
-    def execute_pytest(self, p_rel_path="pytest"):
+    def execute_pytest(self, p_base_dir=None, p_rel_path="pytest"):
 
-        pytest_dir = os.path.join(os.path.dirname(__file__), p_rel_path)
+        if p_base_dir is None:
+            p_base_dir = os.path.dirname(__file__)
+
+        pytest_dir = os.path.join(p_base_dir, p_rel_path)
 
         fmt = "Executing pytest tests in directory {dirname}"
         self._logger.info(fmt.format(dirname=pytest_dir))
 
-        self.assertEqual(pytest.cmdline.main([pytest_dir]), 0)
\ No newline at end of file
+        pytest_result = pytest.cmdline.main([pytest_dir])
+
+        self.assertEqual(pytest_result, 0)
+
+    def check_list_length(self, p_list, p_length):
+
+        self.assertIsNotNone(p_list)
+        self.assertEqual(len(p_list), p_length)
